@@ -54,7 +54,7 @@ DotFileFormatPlugin::~DotFileFormatPlugin()
 }
 
 DotFileFormatPlugin::DotFileFormatPlugin(QObject* parent, const QList< QVariant >&) :
-    GraphFilePluginInterface(FilePluginFactory::componentData().aboutData(), parent)
+    GraphFilePluginInterface(FilePluginFactory(aboutdata,0).componentData().aboutData(), parent)
 {
 }
 
