@@ -28,12 +28,12 @@
 #include "Data.h"
 #include "Pointer.h"
 #include <CoreTypes.h>
-
 #include "Interface/EditorToolbar.h"
 
 #include "Actions/PropertiesDialogAction.h"
 #include "Actions/AlignAction.h"
 
+#include <KLocale>
 #include <QVBoxLayout>
 #include <QGraphicsItem>
 #include <KDebug>
@@ -76,6 +76,7 @@ public:
     QToolButton *_documentPropertiesButton;
     KComboBox *_dataStructureSelectorCombo;
     QToolButton *_dataStructurePropertiesButton;
+    KPushButton *_removeDataStructureButton;
 
     QSlider *_zoomSlider;
     Document *_document;
@@ -97,10 +98,9 @@ GraphVisualEditor::~GraphVisualEditor()
     // d-pointer is scoped pointer and need not to be deleted
 }
 
+GraphVisualEditor * GraphVisualEditor::_self = 0;
 
-GraphVisualEditor* GraphVisualEditor::_self = 0;
-
-GraphVisualEditor* GraphVisualEditor::self()
+GraphVisualEditor * GraphVisualEditor::self()
 {
     if (!_self) {
         _self = new GraphVisualEditor(0);
@@ -111,8 +111,8 @@ GraphVisualEditor* GraphVisualEditor::self()
 void GraphVisualEditor::resizeEvent(QResizeEvent *event)
 {
     Q_UNUSED(event);
-
-    d->_scene->updateMinSize(size().width(), size().height());
+    // resize whiteboard to editor size
+    d->_scene->resize();
 }
 
 void GraphVisualEditor::setupWidgets()
@@ -152,7 +152,7 @@ void GraphVisualEditor::setupWidgets()
             this, SLOT(updateGraphDocumentList()));
 }
 
-QWidget* GraphVisualEditor::sceneToolbar()
+QWidget * GraphVisualEditor::sceneToolbar()
 {
     QWidget *sceneControls = new QWidget(this);
 
@@ -185,11 +185,11 @@ QWidget* GraphVisualEditor::sceneToolbar()
     addDataStructureButton->setMaximumWidth(24);
     sceneControls->layout()->addWidget(addDataStructureButton);
     // create remove data structure button
-    KPushButton* removeDataStructureButton = new KPushButton(this);
-    removeDataStructureButton->setIcon(KIcon("rocsdelete"));
-    removeDataStructureButton->setToolTip(i18nc("@info:tooltip", "Remove selected data structure."));
-    removeDataStructureButton->setMaximumWidth(24);
-    sceneControls->layout()->addWidget(removeDataStructureButton);
+    d->_removeDataStructureButton = new KPushButton(this);
+    d->_removeDataStructureButton->setIcon(KIcon("rocsdelete"));
+    d->_removeDataStructureButton->setToolTip(i18nc("@info:tooltip", "Remove selected data structure."));
+    d->_removeDataStructureButton->setMaximumWidth(24);
+    sceneControls->layout()->addWidget(d->_removeDataStructureButton);
 
     QSpacerItem *spacerItem = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);
     sceneControls->layout()->addItem(spacerItem);
@@ -200,7 +200,7 @@ QWidget* GraphVisualEditor::sceneToolbar()
             &DocumentManager::self(), SLOT(changeDocument(int)));
     connect(addDataStructureButton, SIGNAL(clicked()),
             this, SLOT(addDataStructure()));
-    connect(removeDataStructureButton, SIGNAL(clicked()),
+    connect(d->_removeDataStructureButton, SIGNAL(clicked()),
             this, SLOT(removeDataStructure()));
 
     // add connections for zoom slider
@@ -320,11 +320,15 @@ void GraphVisualEditor::updateDataStructureList()
 void GraphVisualEditor::addDataStructure()
 {
     DocumentManager::self().activeDocument()->addDataStructure();
+    d->_removeDataStructureButton->setEnabled(true);
 }
 
 void GraphVisualEditor::removeDataStructure()
 {
     DocumentManager::self().activeDocument()->activeDataStructure()->remove();
+    if (DocumentManager::self().activeDocument()->dataStructures().isEmpty()) {
+        d->_removeDataStructureButton->setDisabled(true);
+    }
 }
 
 QList<DataItem*> GraphVisualEditor::selectedNodes() const
